@@ -56,7 +56,6 @@ def set_request_attributes(span: Span, kwargs: Dict[str, Any], operation_type: s
     """Set request attributes on span"""
     if not span.is_recording():
         return
-
     # Set operation type
     span.set_attribute(f"{SpanAttributes.LLM_REQUEST_TYPE}", operation_type)
 
@@ -73,7 +72,7 @@ def set_request_attributes(span: Span, kwargs: Dict[str, Any], operation_type: s
     if kwargs.get("stream") is not None:
         span.set_attribute("gen_ai.stream", kwargs["stream"])
 
-    # Chat-specific attributes
+    # Chat Completion API
     if operation_type == "chat" and kwargs.get("messages"):
         messages = kwargs["messages"]
         if isinstance(messages, list) and len(messages) > 0:
@@ -85,46 +84,95 @@ def set_request_attributes(span: Span, kwargs: Dict[str, Any], operation_type: s
                     span.set_attribute(f"{SpanAttributes.LLM_PROMPTS}.{index}.role", message.get("role", "user"))
                     span.set_attribute(f"{SpanAttributes.LLM_PROMPTS}.{index}.content", str(message.get("content", "")))
 
-    # Response-specific attributes
+    # Response API attributes
     if operation_type == "response":
         if kwargs.get("instructions"):
-            span.set_attribute("gen_ai.instructions", kwargs["instructions"])
+            span.set_attribute(f"{SpanAttributes.LLM_PROMPTS}.0.role", "system")
+            span.set_attribute(f"{SpanAttributes.LLM_PROMPTS}.0.content", kwargs["instructions"])
         if kwargs.get("input"):
-            span.set_attribute("gen_ai.input", kwargs["input"])
+            has_instructions = kwargs.get("instructions") is not None
+            if isinstance(kwargs["input"], list) and len(kwargs["input"]) > 0:
+                start_index = 1 if has_instructions else 0
+                for index, message in enumerate(kwargs["input"]):
+                    idx = start_index + index
+                    if hasattr(message, "content"):
+                        span.set_attribute(f"{SpanAttributes.LLM_PROMPTS}.{idx}.role", message.role)
+                        span.set_attribute(f"{SpanAttributes.LLM_PROMPTS}.{idx}.content", message.content)
+                    elif isinstance(message, dict):
+                        span.set_attribute(f"{SpanAttributes.LLM_PROMPTS}.{idx}.role", message.get("role", "user"))
+                        span.set_attribute(
+                            f"{SpanAttributes.LLM_PROMPTS}.{idx}.content", str(message.get("content", ""))
+                        )
+            elif isinstance(kwargs["input"], str):
+                target_index = 1 if has_instructions else 0
+                span.set_attribute(f"{SpanAttributes.LLM_PROMPTS}.{target_index}.role", "user")
+                span.set_attribute(f"{SpanAttributes.LLM_PROMPTS}.{target_index}.content", kwargs["input"])
 
 
 def set_response_attributes(span: Span, response_dict: Dict[str, Any]) -> None:
     """Set response attributes on span"""
     if not span.is_recording():
         return
-
     if response_dict.get("model"):
         span.set_attribute(f"{SpanAttributes.LLM_RESPONSE_MODEL}", response_dict["model"])
 
     if response_dict.get("id"):
         span.set_attribute("gen_ai.response.id", response_dict["id"])
 
-    # Usage information
+    # Usage information (support both chat/completions and responses APIs)
     usage = response_dict.get("usage", {})
     if usage:
-        if usage.get("prompt_tokens"):
-            span.set_attribute(f"{SpanAttributes.LLM_USAGE_PROMPT_TOKENS}", usage["prompt_tokens"])
-        if usage.get("completion_tokens"):
-            span.set_attribute(f"{SpanAttributes.LLM_USAGE_COMPLETION_TOKENS}", usage["completion_tokens"])
-        if usage.get("cache_read_input_token"):
-            span.set_attribute(f"{SpanAttributes.LLM_USAGE_CACHE_READ_INPUT_TOKENS}", usage["cache_read_input_token"])
-        if usage.get("total_tokens"):
+        # Legacy keys (chat/completions)
+        prompt_tokens = usage.get("prompt_tokens")
+        completion_tokens = usage.get("completion_tokens")
+        prompt_tokens_details = usage.get("prompt_tokens_details", {})
+        # Newer keys (responses API)
+        input_tokens = usage.get("input_tokens")
+        output_tokens = usage.get("output_tokens")
+        input_tokens_details = usage.get("input_tokens_details", {})
+
+        # Normalize prompt/input tokens
+        normalized_prompt = prompt_tokens if prompt_tokens is not None else input_tokens
+        normalized_completion = completion_tokens if completion_tokens is not None else output_tokens
+        cache_read_input_tokens = (
+            prompt_tokens_details.get("cached_tokens") or input_tokens_details.get("cached_tokens") or 0
+        )
+
+        if normalized_prompt is not None:
+            span.set_attribute(f"{SpanAttributes.LLM_USAGE_PROMPT_TOKENS}", normalized_prompt)
+        if normalized_completion is not None:
+            span.set_attribute(f"{SpanAttributes.LLM_USAGE_COMPLETION_TOKENS}", normalized_completion)
+        if cache_read_input_tokens:
+            span.set_attribute(f"{SpanAttributes.LLM_USAGE_CACHE_READ_INPUT_TOKENS}", cache_read_input_tokens)
+        if usage.get("total_tokens") is not None:
             span.set_attribute(f"{SpanAttributes.LLM_USAGE_TOTAL_TOKENS}", usage["total_tokens"])
+        if usage.get("output_tokens_details"):
+            span.set_attribute("gen_ai.usage.output_tokens_details", usage["output_tokens_details"])
 
     # Response content
     choices = response_dict.get("choices", [])
-    for index, choice in enumerate(choices):
-        if choice.get("message", {}).get("role"):
-            span.set_attribute(f"{SpanAttributes.LLM_COMPLETIONS}.{index}.role", choice["message"]["role"])
-        if choice.get("message", {}).get("content"):
-            span.set_attribute(f"{SpanAttributes.LLM_COMPLETIONS}.{index}.content", choice["message"]["content"])
-        if choice.get("finish_reason"):
-            span.set_attribute(f"{SpanAttributes.LLM_COMPLETIONS}.{index}.finish_reason", choice["finish_reason"])
+    if choices:
+        for index, choice in enumerate(choices):
+            if choice.get("message", {}).get("role"):
+                span.set_attribute(f"{SpanAttributes.LLM_COMPLETIONS}.{index}.role", choice["message"]["role"])
+            # Prefer chat message content when present, else fallback to text completions
+            message_content = choice.get("message", {}).get("content")
+            if message_content:
+                span.set_attribute(f"{SpanAttributes.LLM_COMPLETIONS}.{index}.content", message_content)
+            elif choice.get("text"):
+                span.set_attribute(f"{SpanAttributes.LLM_COMPLETIONS}.{index}.content", choice["text"])
+            if choice.get("finish_reason"):
+                span.set_attribute(f"{SpanAttributes.LLM_COMPLETIONS}.{index}.finish_reason", choice["finish_reason"])
+
+    if response_dict.get("output"):
+        span.set_attribute(f"{SpanAttributes.LLM_COMPLETIONS}.0.role", "assistant")
+        try:
+            span.set_attribute(
+                f"{SpanAttributes.LLM_COMPLETIONS}.0.content",
+                response_dict["output"][0]["content"][0]["text"],
+            )
+        except Exception:
+            pass
 
     # For responses.create
     if response_dict.get("output_text"):
@@ -485,6 +533,19 @@ class StreamingWrapper(ObjectProxy):  # type: ignore[misc]
         self._request_kwargs = request_kwargs
         self._complete_response: Dict[str, Any] = {"choices": [], "model": ""}
 
+    def _is_chat(self) -> bool:
+        """Best-effort detection for chat vs completion request."""
+        # Presence of "messages" strongly indicates chat endpoints
+        return isinstance(self._request_kwargs, dict) and "messages" in self._request_kwargs
+
+    def _ensure_choice(self, index: int) -> None:
+        """Ensure choices list has an entry at index."""
+        while len(self._complete_response["choices"]) <= index:
+            if self._is_chat():
+                self._complete_response["choices"].append({"message": {"role": "assistant", "content": ""}})
+            else:
+                self._complete_response["choices"].append({"text": ""})
+
     def __iter__(self) -> Iterator[Any]:
         return self
 
@@ -505,6 +566,39 @@ class StreamingWrapper(ObjectProxy):  # type: ignore[misc]
         if chunk_dict.get("model"):
             self._complete_response["model"] = chunk_dict["model"]
 
+        # Aggregate choices/content for chat and completion streams
+        choices = chunk_dict.get("choices") or []
+        if isinstance(choices, list):
+            for choice in choices:
+                try:
+                    idx = int(choice.get("index", 0))
+                except Exception:
+                    idx = 0
+                self._ensure_choice(idx)
+
+                # Chat streaming: content in choices[].delta.content
+                delta = choice.get("delta") or {}
+                content_piece = None
+                if isinstance(delta, dict) and delta.get("content"):
+                    content_piece = str(delta.get("content", ""))
+                    self._complete_response["choices"][idx].setdefault("message", {"role": "assistant", "content": ""})
+                    self._complete_response["choices"][idx]["message"]["content"] += content_piece
+
+                # Legacy/text completion streaming: content in choices[].text
+                if content_piece is None and choice.get("text"):
+                    text_piece = str(choice.get("text", ""))
+                    self._complete_response["choices"][idx]["text"] = (
+                        self._complete_response["choices"][idx].get("text", "") + text_piece
+                    )
+
+                # Finish reason when available
+                if choice.get("finish_reason"):
+                    self._complete_response["choices"][idx]["finish_reason"] = choice.get("finish_reason")
+
+        # Usage sometimes appears in the final chunk if include_usage=True
+        if chunk_dict.get("usage") and isinstance(chunk_dict["usage"], dict):
+            self._complete_response["usage"] = chunk_dict["usage"]
+
         # Add chunk event
         self._span.add_event("llm.content.completion.chunk")
 
@@ -531,6 +625,18 @@ class AsyncStreamingWrapper(ObjectProxy):  # type: ignore[misc]
         self._request_kwargs = request_kwargs
         self._complete_response: Dict[str, Any] = {"choices": [], "model": ""}
 
+    def _is_chat(self) -> bool:
+        """Best-effort detection for chat vs completion request."""
+        return isinstance(self._request_kwargs, dict) and "messages" in self._request_kwargs
+
+    def _ensure_choice(self, index: int) -> None:
+        """Ensure choices list has an entry at index."""
+        while len(self._complete_response["choices"]) <= index:
+            if self._is_chat():
+                self._complete_response["choices"].append({"message": {"role": "assistant", "content": ""}})
+            else:
+                self._complete_response["choices"].append({"text": ""})
+
     def __aiter__(self) -> AsyncIterator[Any]:
         return self
 
@@ -551,6 +657,39 @@ class AsyncStreamingWrapper(ObjectProxy):  # type: ignore[misc]
         if chunk_dict.get("model"):
             self._complete_response["model"] = chunk_dict["model"]
 
+        # Aggregate choices/content for chat and completion streams
+        choices = chunk_dict.get("choices") or []
+        if isinstance(choices, list):
+            for choice in choices:
+                try:
+                    idx = int(choice.get("index", 0))
+                except Exception:
+                    idx = 0
+                self._ensure_choice(idx)
+
+                # Chat streaming: content in choices[].delta.content
+                delta = choice.get("delta") or {}
+                content_piece = None
+                if isinstance(delta, dict) and delta.get("content"):
+                    content_piece = str(delta.get("content", ""))
+                    self._complete_response["choices"][idx].setdefault("message", {"role": "assistant", "content": ""})
+                    self._complete_response["choices"][idx]["message"]["content"] += content_piece
+
+                # Legacy/text completion streaming: content in choices[].text
+                if content_piece is None and choice.get("text"):
+                    text_piece = str(choice.get("text", ""))
+                    self._complete_response["choices"][idx]["text"] = (
+                        self._complete_response["choices"][idx].get("text", "") + text_piece
+                    )
+
+                # Finish reason when available
+                if choice.get("finish_reason"):
+                    self._complete_response["choices"][idx]["finish_reason"] = choice.get("finish_reason")
+
+        # Usage sometimes appears in the final chunk if include_usage=True
+        if chunk_dict.get("usage") and isinstance(chunk_dict["usage"], dict):
+            self._complete_response["usage"] = chunk_dict["usage"]
+
         # Add chunk event
         self._span.add_event("llm.content.completion.chunk")
 
