@@ -1,5 +1,11 @@
 from netra.processors.instrumentation_span_processor import InstrumentationSpanProcessor
+from netra.processors.local_filtering_span_processor import LocalFilteringSpanProcessor
 from netra.processors.scrubbing_span_processor import ScrubbingSpanProcessor
 from netra.processors.session_span_processor import SessionSpanProcessor
 
-__all__ = ["SessionSpanProcessor", "InstrumentationSpanProcessor", "ScrubbingSpanProcessor"]
+__all__ = [
+    "SessionSpanProcessor",
+    "InstrumentationSpanProcessor",
+    "ScrubbingSpanProcessor",
+    "LocalFilteringSpanProcessor",
+]
